edition2024

package
v0.5.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 14, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

const I18NVariable_OneOfValues_not_set_case case_I18NVariable_OneOfValues = 0
const I18NVariable_OptOne_case case_I18NVariable_OneOfValues = 1
const I18NVariable_OptTwo_case case_I18NVariable_OneOfValues = 2
const Msg_OneOfValues_not_set_case case_Msg_OneOfValues = 0
const Msg_Tags_case case_Msg_OneOfValues = 1
const OneOfs_Bools_case case_OneOfs_Thing = 1
const OneOfs_Doubles_case case_OneOfs_Thing = 17
const OneOfs_Fixed32S_case case_OneOfs_Thing = 9
const OneOfs_Fixed64S_case case_OneOfs_Thing = 10
const OneOfs_Floats_case case_OneOfs_Thing = 16
const OneOfs_Int32S_case case_OneOfs_Thing = 3
const OneOfs_Int64S_case case_OneOfs_Thing = 4
const OneOfs_Nulls_case case_OneOfs_Thing = 13
const OneOfs_Objects_case case_OneOfs_Thing = 30
const OneOfs_Sfixed32S_case case_OneOfs_Thing = 11
const OneOfs_Sfixed64S_case case_OneOfs_Thing = 12
const OneOfs_Sint32S_case case_OneOfs_Thing = 7
const OneOfs_Sint64S_case case_OneOfs_Thing = 8
const OneOfs_Strings_case case_OneOfs_Thing = 2
const OneOfs_Structs_case case_OneOfs_Thing = 14
const OneOfs_Thing_not_set_case case_OneOfs_Thing = 0
const OneOfs_Timestamps_case case_OneOfs_Thing = 15
const OneOfs_Uint32S_case case_OneOfs_Thing = 5
const OneOfs_Uint64S_case case_OneOfs_Thing = 6
const TestEvent_Jedi_case case_TestEvent_Path = 6
const TestEvent_Oneofs_not_set_case case_TestEvent_Oneofs = 0
const TestEvent_Other_case case_TestEvent_Path = 8
const TestEvent_Path_not_set_case case_TestEvent_Path = 0
const TestEvent_Sith_case case_TestEvent_Path = 7
const TestEvent_Structs_case case_TestEvent_Oneofs = 13
const TestEvent_Timestamps_case case_TestEvent_Oneofs = 12

Variables

var (
	EventType_name = map[int32]string{
		0: "EVENT_TYPE_UNDEFINED",
		1: "EVENT_TYPE_ONE",
		2: "EVENT_TYPE_TWO",
	}
	EventType_value = map[string]int32{
		"EVENT_TYPE_UNDEFINED": 0,
		"EVENT_TYPE_ONE":       1,
		"EVENT_TYPE_TWO":       2,
	}
)

Enum value maps for EventType.

var File_edition2024_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AllTheThings

type AllTheThings struct {
	XXX_raceDetectHookData protoimpl.RaceDetectHookData
	XXX_presence           [1]uint32
	// contains filtered or unexported fields
}

func (*AllTheThings) ClearId

func (x *AllTheThings) ClearId()

func (*AllTheThings) ClearTheBool

func (x *AllTheThings) ClearTheBool()

func (*AllTheThings) ClearTheBytes

func (x *AllTheThings) ClearTheBytes()

func (*AllTheThings) ClearTheDouble

func (x *AllTheThings) ClearTheDouble()

func (*AllTheThings) ClearTheEventType

func (x *AllTheThings) ClearTheEventType()

func (*AllTheThings) ClearTheFixed32

func (x *AllTheThings) ClearTheFixed32()

func (*AllTheThings) ClearTheFixed64

func (x *AllTheThings) ClearTheFixed64()

func (*AllTheThings) ClearTheFloat

func (x *AllTheThings) ClearTheFloat()

func (*AllTheThings) ClearTheInt32

func (x *AllTheThings) ClearTheInt32()

func (*AllTheThings) ClearTheInt64

func (x *AllTheThings) ClearTheInt64()

func (*AllTheThings) ClearTheMessage

func (x *AllTheThings) ClearTheMessage()

func (*AllTheThings) ClearTheSfixed32

func (x *AllTheThings) ClearTheSfixed32()

func (*AllTheThings) ClearTheSfixed64

func (x *AllTheThings) ClearTheSfixed64()

func (*AllTheThings) ClearTheSint32

func (x *AllTheThings) ClearTheSint32()

func (*AllTheThings) ClearTheSint64

func (x *AllTheThings) ClearTheSint64()

func (*AllTheThings) ClearTheString

func (x *AllTheThings) ClearTheString()

func (*AllTheThings) ClearTheUint32

func (x *AllTheThings) ClearTheUint32()

func (*AllTheThings) ClearTheUint64

func (x *AllTheThings) ClearTheUint64()

func (*AllTheThings) GetId

func (x *AllTheThings) GetId() int32

func (*AllTheThings) GetTheBool

func (x *AllTheThings) GetTheBool() bool

func (*AllTheThings) GetTheBytes

func (x *AllTheThings) GetTheBytes() []byte

func (*AllTheThings) GetTheDouble

func (x *AllTheThings) GetTheDouble() float64

func (*AllTheThings) GetTheEventType

func (x *AllTheThings) GetTheEventType() EventType

func (*AllTheThings) GetTheFixed32

func (x *AllTheThings) GetTheFixed32() uint32

func (*AllTheThings) GetTheFixed64

func (x *AllTheThings) GetTheFixed64() uint64

func (*AllTheThings) GetTheFloat

func (x *AllTheThings) GetTheFloat() float32

func (*AllTheThings) GetTheInt32

func (x *AllTheThings) GetTheInt32() int32

func (*AllTheThings) GetTheInt64

func (x *AllTheThings) GetTheInt64() int64

func (*AllTheThings) GetTheMessage

func (x *AllTheThings) GetTheMessage() *EmbeddedEvent

func (*AllTheThings) GetTheSfixed32

func (x *AllTheThings) GetTheSfixed32() int32

func (*AllTheThings) GetTheSfixed64

func (x *AllTheThings) GetTheSfixed64() int64

func (*AllTheThings) GetTheSint32

func (x *AllTheThings) GetTheSint32() int32

func (*AllTheThings) GetTheSint64

func (x *AllTheThings) GetTheSint64() int64

func (*AllTheThings) GetTheString

func (x *AllTheThings) GetTheString() string

func (*AllTheThings) GetTheUint32

func (x *AllTheThings) GetTheUint32() uint32

func (*AllTheThings) GetTheUint64

func (x *AllTheThings) GetTheUint64() uint64

func (*AllTheThings) HasId

func (x *AllTheThings) HasId() bool

func (*AllTheThings) HasTheBool

func (x *AllTheThings) HasTheBool() bool

func (*AllTheThings) HasTheBytes

func (x *AllTheThings) HasTheBytes() bool

func (*AllTheThings) HasTheDouble

func (x *AllTheThings) HasTheDouble() bool

func (*AllTheThings) HasTheEventType

func (x *AllTheThings) HasTheEventType() bool

func (*AllTheThings) HasTheFixed32

func (x *AllTheThings) HasTheFixed32() bool

func (*AllTheThings) HasTheFixed64

func (x *AllTheThings) HasTheFixed64() bool

func (*AllTheThings) HasTheFloat

func (x *AllTheThings) HasTheFloat() bool

func (*AllTheThings) HasTheInt32

func (x *AllTheThings) HasTheInt32() bool

func (*AllTheThings) HasTheInt64

func (x *AllTheThings) HasTheInt64() bool

func (*AllTheThings) HasTheMessage

func (x *AllTheThings) HasTheMessage() bool

func (*AllTheThings) HasTheSfixed32

func (x *AllTheThings) HasTheSfixed32() bool

func (*AllTheThings) HasTheSfixed64

func (x *AllTheThings) HasTheSfixed64() bool

func (*AllTheThings) HasTheSint32

func (x *AllTheThings) HasTheSint32() bool

func (*AllTheThings) HasTheSint64

func (x *AllTheThings) HasTheSint64() bool

func (*AllTheThings) HasTheString

func (x *AllTheThings) HasTheString() bool

func (*AllTheThings) HasTheUint32

func (x *AllTheThings) HasTheUint32() bool

func (*AllTheThings) HasTheUint64

func (x *AllTheThings) HasTheUint64() bool

func (*AllTheThings) Marshal

func (m *AllTheThings) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*AllTheThings) MarshalSize added in v0.4.0

func (m *AllTheThings) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*AllTheThings) MarshalTo

func (m *AllTheThings) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*AllTheThings) ProtoMessage

func (*AllTheThings) ProtoMessage()

func (*AllTheThings) ProtoReflect

func (x *AllTheThings) ProtoReflect() protoreflect.Message

func (*AllTheThings) Reset

func (x *AllTheThings) Reset()

func (*AllTheThings) SetId

func (x *AllTheThings) SetId(v int32)

func (*AllTheThings) SetTheBool

func (x *AllTheThings) SetTheBool(v bool)

func (*AllTheThings) SetTheBytes

func (x *AllTheThings) SetTheBytes(v []byte)

func (*AllTheThings) SetTheDouble

func (x *AllTheThings) SetTheDouble(v float64)

func (*AllTheThings) SetTheEventType

func (x *AllTheThings) SetTheEventType(v EventType)

func (*AllTheThings) SetTheFixed32

func (x *AllTheThings) SetTheFixed32(v uint32)

func (*AllTheThings) SetTheFixed64

func (x *AllTheThings) SetTheFixed64(v uint64)

func (*AllTheThings) SetTheFloat

func (x *AllTheThings) SetTheFloat(v float32)

func (*AllTheThings) SetTheInt32

func (x *AllTheThings) SetTheInt32(v int32)

func (*AllTheThings) SetTheInt64

func (x *AllTheThings) SetTheInt64(v int64)

func (*AllTheThings) SetTheMessage

func (x *AllTheThings) SetTheMessage(v *EmbeddedEvent)

func (*AllTheThings) SetTheSfixed32

func (x *AllTheThings) SetTheSfixed32(v int32)

func (*AllTheThings) SetTheSfixed64

func (x *AllTheThings) SetTheSfixed64(v int64)

func (*AllTheThings) SetTheSint32

func (x *AllTheThings) SetTheSint32(v int32)

func (*AllTheThings) SetTheSint64

func (x *AllTheThings) SetTheSint64(v int64)

func (*AllTheThings) SetTheString

func (x *AllTheThings) SetTheString(v string)

func (*AllTheThings) SetTheUint32

func (x *AllTheThings) SetTheUint32(v uint32)

func (*AllTheThings) SetTheUint64

func (x *AllTheThings) SetTheUint64(v uint64)

func (*AllTheThings) String

func (x *AllTheThings) String() string

func (*AllTheThings) Unmarshal

func (m *AllTheThings) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

type AllTheThings_builder

type AllTheThings_builder struct {
	Id           *int32
	TheString    *string
	TheBool      *bool
	TheInt32     *int32
	TheInt64     *int64
	TheUint32    *uint32
	TheUint64    *uint64
	TheSint32    *int32
	TheSint64    *int64
	TheFixed32   *uint32
	TheFixed64   *uint64
	TheSfixed32  *int32
	TheSfixed64  *int64
	TheFloat     *float32
	TheDouble    *float64
	TheEventType *EventType
	TheBytes     []byte
	TheMessage   *EmbeddedEvent
	// contains filtered or unexported fields
}

func (AllTheThings_builder) Build

func (b0 AllTheThings_builder) Build() *AllTheThings

type EmbeddedEvent

type EmbeddedEvent struct {
	Id              *int32   `protobuf:"varint,1,opt,name=id" json:"id,omitempty"`
	Stuff           *string  `protobuf:"bytes,2,opt,name=stuff" json:"stuff,omitempty"`
	FavoriteNumbers []int32  `protobuf:"varint,3,rep,packed,name=favorite_numbers,json=favoriteNumbers" json:"favorite_numbers,omitempty"`
	RandomThings    [][]byte `protobuf:"bytes,4,rep,name=random_things,json=randomThings" json:"random_things,omitempty"`
	// contains filtered or unexported fields
}

func (*EmbeddedEvent) Descriptor deprecated

func (*EmbeddedEvent) Descriptor() ([]byte, []int)

Deprecated: Use EmbeddedEvent.ProtoReflect.Descriptor instead.

func (*EmbeddedEvent) GetFavoriteNumbers

func (x *EmbeddedEvent) GetFavoriteNumbers() []int32

func (*EmbeddedEvent) GetId

func (x *EmbeddedEvent) GetId() int32

func (*EmbeddedEvent) GetRandomThings

func (x *EmbeddedEvent) GetRandomThings() [][]byte

func (*EmbeddedEvent) GetStuff

func (x *EmbeddedEvent) GetStuff() string

func (*EmbeddedEvent) Marshal

func (m *EmbeddedEvent) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*EmbeddedEvent) MarshalSize added in v0.4.0

func (m *EmbeddedEvent) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*EmbeddedEvent) MarshalTo

func (m *EmbeddedEvent) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*EmbeddedEvent) ProtoMessage

func (*EmbeddedEvent) ProtoMessage()

func (*EmbeddedEvent) ProtoReflect

func (x *EmbeddedEvent) ProtoReflect() protoreflect.Message

func (*EmbeddedEvent) Reset

func (x *EmbeddedEvent) Reset()

func (*EmbeddedEvent) String

func (x *EmbeddedEvent) String() string

func (*EmbeddedEvent) Unmarshal

func (m *EmbeddedEvent) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

type EventType

type EventType int32
const (
	EventType_EVENT_TYPE_UNDEFINED EventType = 0
	EventType_EVENT_TYPE_ONE       EventType = 1
	EventType_EVENT_TYPE_TWO       EventType = 2
)

func (EventType) Descriptor

func (EventType) Descriptor() protoreflect.EnumDescriptor

func (EventType) Enum

func (x EventType) Enum() *EventType

func (EventType) Number

func (x EventType) Number() protoreflect.EnumNumber

func (EventType) String

func (x EventType) String() string

func (EventType) Type

type EventUsingWKTs

type EventUsingWKTs struct {
	XXX_raceDetectHookData protoimpl.RaceDetectHookData
	XXX_presence           [1]uint32
	// contains filtered or unexported fields
}

func (*EventUsingWKTs) ClearEventType

func (x *EventUsingWKTs) ClearEventType()

func (*EventUsingWKTs) ClearName

func (x *EventUsingWKTs) ClearName()

func (*EventUsingWKTs) ClearTs

func (x *EventUsingWKTs) ClearTs()

func (*EventUsingWKTs) GetEventType

func (x *EventUsingWKTs) GetEventType() EventType

func (*EventUsingWKTs) GetName

func (x *EventUsingWKTs) GetName() string

func (*EventUsingWKTs) GetTs

func (x *EventUsingWKTs) GetTs() *timestamppb.Timestamp

func (*EventUsingWKTs) HasEventType

func (x *EventUsingWKTs) HasEventType() bool

func (*EventUsingWKTs) HasName

func (x *EventUsingWKTs) HasName() bool

func (*EventUsingWKTs) HasTs

func (x *EventUsingWKTs) HasTs() bool

func (*EventUsingWKTs) Marshal

func (m *EventUsingWKTs) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*EventUsingWKTs) MarshalSize added in v0.4.0

func (m *EventUsingWKTs) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*EventUsingWKTs) MarshalTo

func (m *EventUsingWKTs) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*EventUsingWKTs) ProtoMessage

func (*EventUsingWKTs) ProtoMessage()

func (*EventUsingWKTs) ProtoReflect

func (x *EventUsingWKTs) ProtoReflect() protoreflect.Message

func (*EventUsingWKTs) Reset

func (x *EventUsingWKTs) Reset()

func (*EventUsingWKTs) SetEventType

func (x *EventUsingWKTs) SetEventType(v EventType)

func (*EventUsingWKTs) SetName

func (x *EventUsingWKTs) SetName(v string)

func (*EventUsingWKTs) SetTs

func (x *EventUsingWKTs) SetTs(v *timestamppb.Timestamp)

func (*EventUsingWKTs) String

func (x *EventUsingWKTs) String() string

func (*EventUsingWKTs) Unmarshal

func (m *EventUsingWKTs) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

type EventUsingWKTs_builder

type EventUsingWKTs_builder struct {
	Name      *string
	Ts        *timestamppb.Timestamp
	EventType *EventType
	// contains filtered or unexported fields
}

func (EventUsingWKTs_builder) Build

type I18NVariable

type I18NVariable struct {
	// contains filtered or unexported fields
}

func (*I18NVariable) ClearOneOfValues

func (x *I18NVariable) ClearOneOfValues()

func (*I18NVariable) ClearOptOne

func (x *I18NVariable) ClearOptOne()

func (*I18NVariable) ClearOptTwo

func (x *I18NVariable) ClearOptTwo()

func (*I18NVariable) GetOptOne

func (x *I18NVariable) GetOptOne() string

func (*I18NVariable) GetOptTwo

func (x *I18NVariable) GetOptTwo() string

func (*I18NVariable) HasOneOfValues

func (x *I18NVariable) HasOneOfValues() bool

func (*I18NVariable) HasOptOne

func (x *I18NVariable) HasOptOne() bool

func (*I18NVariable) HasOptTwo

func (x *I18NVariable) HasOptTwo() bool

func (*I18NVariable) Marshal

func (m *I18NVariable) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*I18NVariable) MarshalSize added in v0.4.0

func (m *I18NVariable) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*I18NVariable) MarshalTo

func (m *I18NVariable) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*I18NVariable) ProtoMessage

func (*I18NVariable) ProtoMessage()

func (*I18NVariable) ProtoReflect

func (x *I18NVariable) ProtoReflect() protoreflect.Message

func (*I18NVariable) Reset

func (x *I18NVariable) Reset()

func (*I18NVariable) SetOptOne

func (x *I18NVariable) SetOptOne(v string)

func (*I18NVariable) SetOptTwo

func (x *I18NVariable) SetOptTwo(v string)

func (*I18NVariable) String

func (x *I18NVariable) String() string

func (*I18NVariable) Unmarshal

func (m *I18NVariable) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

func (*I18NVariable) WhichOneOfValues

func (x *I18NVariable) WhichOneOfValues() case_I18NVariable_OneOfValues

type I18NVariable_builder

type I18NVariable_builder struct {

	// Fields of oneof xxx_hidden_OneOfValues:
	OptOne *string
	OptTwo *string
	// contains filtered or unexported fields
}

func (I18NVariable_builder) Build

func (b0 I18NVariable_builder) Build() *I18NVariable

type MapObject

type MapObject struct {
	XXX_raceDetectHookData protoimpl.RaceDetectHookData
	XXX_presence           [1]uint32
	// contains filtered or unexported fields
}

func (*MapObject) ClearName

func (x *MapObject) ClearName()

func (*MapObject) ClearTs

func (x *MapObject) ClearTs()

func (*MapObject) GetAttributes

func (x *MapObject) GetAttributes() map[string]string

func (*MapObject) GetName

func (x *MapObject) GetName() string

func (*MapObject) GetTs

func (x *MapObject) GetTs() *timestamppb.Timestamp

func (*MapObject) HasName

func (x *MapObject) HasName() bool

func (*MapObject) HasTs

func (x *MapObject) HasTs() bool

func (*MapObject) Marshal

func (m *MapObject) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*MapObject) MarshalSize added in v0.4.0

func (m *MapObject) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*MapObject) MarshalTo

func (m *MapObject) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*MapObject) ProtoMessage

func (*MapObject) ProtoMessage()

func (*MapObject) ProtoReflect

func (x *MapObject) ProtoReflect() protoreflect.Message

func (*MapObject) Reset

func (x *MapObject) Reset()

func (*MapObject) SetAttributes

func (x *MapObject) SetAttributes(v map[string]string)

func (*MapObject) SetName

func (x *MapObject) SetName(v string)

func (*MapObject) SetTs

func (x *MapObject) SetTs(v *timestamppb.Timestamp)

func (*MapObject) String

func (x *MapObject) String() string

func (*MapObject) Unmarshal

func (m *MapObject) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

type MapObject_builder

type MapObject_builder struct {
	Name       *string
	Ts         *timestamppb.Timestamp
	Attributes map[string]string
	// contains filtered or unexported fields
}

func (MapObject_builder) Build

func (b0 MapObject_builder) Build() *MapObject

type Maps

type Maps struct {
	// contains filtered or unexported fields
}

func (*Maps) GetBools

func (x *Maps) GetBools() map[string]bool

func (*Maps) GetDoubles

func (x *Maps) GetDoubles() map[string]float64

func (*Maps) GetFixed32S

func (x *Maps) GetFixed32S() map[uint32]uint32

func (*Maps) GetFixed64S

func (x *Maps) GetFixed64S() map[uint64]uint64

func (*Maps) GetFloats

func (x *Maps) GetFloats() map[string]float32

func (*Maps) GetInt32S

func (x *Maps) GetInt32S() map[int32]int32

func (*Maps) GetInt64S

func (x *Maps) GetInt64S() map[int64]int64

func (*Maps) GetNulls

func (x *Maps) GetNulls() map[string]structpb.NullValue

func (*Maps) GetObjects

func (x *Maps) GetObjects() map[string]*MapObject

func (*Maps) GetSfixed32S

func (x *Maps) GetSfixed32S() map[int32]int32

func (*Maps) GetSfixed64S

func (x *Maps) GetSfixed64S() map[int64]int64

func (*Maps) GetSint32S

func (x *Maps) GetSint32S() map[int32]int32

func (*Maps) GetSint64S

func (x *Maps) GetSint64S() map[int64]int64

func (*Maps) GetStrings

func (x *Maps) GetStrings() map[string]string

func (*Maps) GetStructs

func (x *Maps) GetStructs() map[string]*structpb.Struct

func (*Maps) GetTimestamps

func (x *Maps) GetTimestamps() map[string]*timestamppb.Timestamp

func (*Maps) GetUint32S

func (x *Maps) GetUint32S() map[uint32]uint32

func (*Maps) GetUint64S

func (x *Maps) GetUint64S() map[uint64]uint64

func (*Maps) Marshal

func (m *Maps) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*Maps) MarshalSize added in v0.4.0

func (m *Maps) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*Maps) MarshalTo

func (m *Maps) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*Maps) ProtoMessage

func (*Maps) ProtoMessage()

func (*Maps) ProtoReflect

func (x *Maps) ProtoReflect() protoreflect.Message

func (*Maps) Reset

func (x *Maps) Reset()

func (*Maps) SetBools

func (x *Maps) SetBools(v map[string]bool)

func (*Maps) SetDoubles

func (x *Maps) SetDoubles(v map[string]float64)

func (*Maps) SetFixed32S

func (x *Maps) SetFixed32S(v map[uint32]uint32)

func (*Maps) SetFixed64S

func (x *Maps) SetFixed64S(v map[uint64]uint64)

func (*Maps) SetFloats

func (x *Maps) SetFloats(v map[string]float32)

func (*Maps) SetInt32S

func (x *Maps) SetInt32S(v map[int32]int32)

func (*Maps) SetInt64S

func (x *Maps) SetInt64S(v map[int64]int64)

func (*Maps) SetNulls

func (x *Maps) SetNulls(v map[string]structpb.NullValue)

func (*Maps) SetObjects

func (x *Maps) SetObjects(v map[string]*MapObject)

func (*Maps) SetSfixed32S

func (x *Maps) SetSfixed32S(v map[int32]int32)

func (*Maps) SetSfixed64S

func (x *Maps) SetSfixed64S(v map[int64]int64)

func (*Maps) SetSint32S

func (x *Maps) SetSint32S(v map[int32]int32)

func (*Maps) SetSint64S

func (x *Maps) SetSint64S(v map[int64]int64)

func (*Maps) SetStrings

func (x *Maps) SetStrings(v map[string]string)

func (*Maps) SetStructs

func (x *Maps) SetStructs(v map[string]*structpb.Struct)

func (*Maps) SetTimestamps

func (x *Maps) SetTimestamps(v map[string]*timestamppb.Timestamp)

func (*Maps) SetUint32S

func (x *Maps) SetUint32S(v map[uint32]uint32)

func (*Maps) SetUint64S

func (x *Maps) SetUint64S(v map[uint64]uint64)

func (*Maps) String

func (x *Maps) String() string

func (*Maps) Unmarshal

func (m *Maps) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

type Maps_builder

type Maps_builder struct {
	Bools      map[string]bool
	Strings    map[string]string
	Int32S     map[int32]int32
	Int64S     map[int64]int64
	Uint32S    map[uint32]uint32
	Uint64S    map[uint64]uint64
	Sint32S    map[int32]int32
	Sint64S    map[int64]int64
	Fixed32S   map[uint32]uint32
	Fixed64S   map[uint64]uint64
	Sfixed32S  map[int32]int32
	Sfixed64S  map[int64]int64
	Floats     map[string]float32
	Doubles    map[string]float64
	Nulls      map[string]structpb.NullValue
	Structs    map[string]*structpb.Struct
	Timestamps map[string]*timestamppb.Timestamp
	Objects    map[string]*MapObject
	// contains filtered or unexported fields
}

func (Maps_builder) Build

func (b0 Maps_builder) Build() *Maps

type Msg

type Msg struct {
	// contains filtered or unexported fields
}

func (*Msg) ClearOneOfValues

func (x *Msg) ClearOneOfValues()

func (*Msg) ClearTags

func (x *Msg) ClearTags()

func (*Msg) GetTags

func (x *Msg) GetTags() *Msg_Tags

func (*Msg) HasOneOfValues

func (x *Msg) HasOneOfValues() bool

func (*Msg) HasTags

func (x *Msg) HasTags() bool

func (*Msg) Marshal

func (m *Msg) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*Msg) MarshalSize added in v0.4.0

func (m *Msg) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*Msg) MarshalTo

func (m *Msg) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*Msg) ProtoMessage

func (*Msg) ProtoMessage()

func (*Msg) ProtoReflect

func (x *Msg) ProtoReflect() protoreflect.Message

func (*Msg) Reset

func (x *Msg) Reset()

func (*Msg) SetTags

func (x *Msg) SetTags(v *Msg_Tags)

func (*Msg) String

func (x *Msg) String() string

func (*Msg) Unmarshal

func (m *Msg) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

func (*Msg) WhichOneOfValues

func (x *Msg) WhichOneOfValues() case_Msg_OneOfValues

type Msg_Tags

type Msg_Tags struct {
	// contains filtered or unexported fields
}

func (*Msg_Tags) GetTags

func (x *Msg_Tags) GetTags() []string

func (*Msg_Tags) Marshal

func (m *Msg_Tags) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*Msg_Tags) MarshalSize added in v0.4.0

func (m *Msg_Tags) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*Msg_Tags) MarshalTo

func (m *Msg_Tags) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*Msg_Tags) ProtoMessage

func (*Msg_Tags) ProtoMessage()

func (*Msg_Tags) ProtoReflect

func (x *Msg_Tags) ProtoReflect() protoreflect.Message

func (*Msg_Tags) Reset

func (x *Msg_Tags) Reset()

func (*Msg_Tags) SetTags

func (x *Msg_Tags) SetTags(v []string)

func (*Msg_Tags) String

func (x *Msg_Tags) String() string

func (*Msg_Tags) Unmarshal

func (m *Msg_Tags) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

type Msg_Tags_builder

type Msg_Tags_builder struct {
	Tags []string
	// contains filtered or unexported fields
}

func (Msg_Tags_builder) Build

func (b0 Msg_Tags_builder) Build() *Msg_Tags

type Msg_builder

type Msg_builder struct {

	// Fields of oneof xxx_hidden_OneOfValues:
	Tags *Msg_Tags
	// contains filtered or unexported fields
}

func (Msg_builder) Build

func (b0 Msg_builder) Build() *Msg

type OneOfs

type OneOfs struct {
	// contains filtered or unexported fields
}

func (*OneOfs) ClearBools

func (x *OneOfs) ClearBools()

func (*OneOfs) ClearDoubles

func (x *OneOfs) ClearDoubles()

func (*OneOfs) ClearFixed32S

func (x *OneOfs) ClearFixed32S()

func (*OneOfs) ClearFixed64S

func (x *OneOfs) ClearFixed64S()

func (*OneOfs) ClearFloats

func (x *OneOfs) ClearFloats()

func (*OneOfs) ClearInt32S

func (x *OneOfs) ClearInt32S()

func (*OneOfs) ClearInt64S

func (x *OneOfs) ClearInt64S()

func (*OneOfs) ClearNulls

func (x *OneOfs) ClearNulls()

func (*OneOfs) ClearObjects

func (x *OneOfs) ClearObjects()

func (*OneOfs) ClearSfixed32S

func (x *OneOfs) ClearSfixed32S()

func (*OneOfs) ClearSfixed64S

func (x *OneOfs) ClearSfixed64S()

func (*OneOfs) ClearSint32S

func (x *OneOfs) ClearSint32S()

func (*OneOfs) ClearSint64S

func (x *OneOfs) ClearSint64S()

func (*OneOfs) ClearStrings

func (x *OneOfs) ClearStrings()

func (*OneOfs) ClearStructs

func (x *OneOfs) ClearStructs()

func (*OneOfs) ClearThing

func (x *OneOfs) ClearThing()

func (*OneOfs) ClearTimestamps

func (x *OneOfs) ClearTimestamps()

func (*OneOfs) ClearUint32S

func (x *OneOfs) ClearUint32S()

func (*OneOfs) ClearUint64S

func (x *OneOfs) ClearUint64S()

func (*OneOfs) GetBools

func (x *OneOfs) GetBools() bool

func (*OneOfs) GetDoubles

func (x *OneOfs) GetDoubles() float64

func (*OneOfs) GetFixed32S

func (x *OneOfs) GetFixed32S() uint32

func (*OneOfs) GetFixed64S

func (x *OneOfs) GetFixed64S() uint64

func (*OneOfs) GetFloats

func (x *OneOfs) GetFloats() float32

func (*OneOfs) GetInt32S

func (x *OneOfs) GetInt32S() int32

func (*OneOfs) GetInt64S

func (x *OneOfs) GetInt64S() int64

func (*OneOfs) GetNulls

func (x *OneOfs) GetNulls() structpb.NullValue

func (*OneOfs) GetObjects

func (x *OneOfs) GetObjects() *MapObject

func (*OneOfs) GetSfixed32S

func (x *OneOfs) GetSfixed32S() int32

func (*OneOfs) GetSfixed64S

func (x *OneOfs) GetSfixed64S() int64

func (*OneOfs) GetSint32S

func (x *OneOfs) GetSint32S() int32

func (*OneOfs) GetSint64S

func (x *OneOfs) GetSint64S() int64

func (*OneOfs) GetStrings

func (x *OneOfs) GetStrings() string

func (*OneOfs) GetStructs

func (x *OneOfs) GetStructs() *structpb.Struct

func (*OneOfs) GetTimestamps

func (x *OneOfs) GetTimestamps() *timestamppb.Timestamp

func (*OneOfs) GetUint32S

func (x *OneOfs) GetUint32S() uint32

func (*OneOfs) GetUint64S

func (x *OneOfs) GetUint64S() uint64

func (*OneOfs) HasBools

func (x *OneOfs) HasBools() bool

func (*OneOfs) HasDoubles

func (x *OneOfs) HasDoubles() bool

func (*OneOfs) HasFixed32S

func (x *OneOfs) HasFixed32S() bool

func (*OneOfs) HasFixed64S

func (x *OneOfs) HasFixed64S() bool

func (*OneOfs) HasFloats

func (x *OneOfs) HasFloats() bool

func (*OneOfs) HasInt32S

func (x *OneOfs) HasInt32S() bool

func (*OneOfs) HasInt64S

func (x *OneOfs) HasInt64S() bool

func (*OneOfs) HasNulls

func (x *OneOfs) HasNulls() bool

func (*OneOfs) HasObjects

func (x *OneOfs) HasObjects() bool

func (*OneOfs) HasSfixed32S

func (x *OneOfs) HasSfixed32S() bool

func (*OneOfs) HasSfixed64S

func (x *OneOfs) HasSfixed64S() bool

func (*OneOfs) HasSint32S

func (x *OneOfs) HasSint32S() bool

func (*OneOfs) HasSint64S

func (x *OneOfs) HasSint64S() bool

func (*OneOfs) HasStrings

func (x *OneOfs) HasStrings() bool

func (*OneOfs) HasStructs

func (x *OneOfs) HasStructs() bool

func (*OneOfs) HasThing

func (x *OneOfs) HasThing() bool

func (*OneOfs) HasTimestamps

func (x *OneOfs) HasTimestamps() bool

func (*OneOfs) HasUint32S

func (x *OneOfs) HasUint32S() bool

func (*OneOfs) HasUint64S

func (x *OneOfs) HasUint64S() bool

func (*OneOfs) Marshal

func (m *OneOfs) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*OneOfs) MarshalSize added in v0.4.0

func (m *OneOfs) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*OneOfs) MarshalTo

func (m *OneOfs) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*OneOfs) ProtoMessage

func (*OneOfs) ProtoMessage()

func (*OneOfs) ProtoReflect

func (x *OneOfs) ProtoReflect() protoreflect.Message

func (*OneOfs) Reset

func (x *OneOfs) Reset()

func (*OneOfs) SetBools

func (x *OneOfs) SetBools(v bool)

func (*OneOfs) SetDoubles

func (x *OneOfs) SetDoubles(v float64)

func (*OneOfs) SetFixed32S

func (x *OneOfs) SetFixed32S(v uint32)

func (*OneOfs) SetFixed64S

func (x *OneOfs) SetFixed64S(v uint64)

func (*OneOfs) SetFloats

func (x *OneOfs) SetFloats(v float32)

func (*OneOfs) SetInt32S

func (x *OneOfs) SetInt32S(v int32)

func (*OneOfs) SetInt64S

func (x *OneOfs) SetInt64S(v int64)

func (*OneOfs) SetNulls

func (x *OneOfs) SetNulls(v structpb.NullValue)

func (*OneOfs) SetObjects

func (x *OneOfs) SetObjects(v *MapObject)

func (*OneOfs) SetSfixed32S

func (x *OneOfs) SetSfixed32S(v int32)

func (*OneOfs) SetSfixed64S

func (x *OneOfs) SetSfixed64S(v int64)

func (*OneOfs) SetSint32S

func (x *OneOfs) SetSint32S(v int32)

func (*OneOfs) SetSint64S

func (x *OneOfs) SetSint64S(v int64)

func (*OneOfs) SetStrings

func (x *OneOfs) SetStrings(v string)

func (*OneOfs) SetStructs

func (x *OneOfs) SetStructs(v *structpb.Struct)

func (*OneOfs) SetTimestamps

func (x *OneOfs) SetTimestamps(v *timestamppb.Timestamp)

func (*OneOfs) SetUint32S

func (x *OneOfs) SetUint32S(v uint32)

func (*OneOfs) SetUint64S

func (x *OneOfs) SetUint64S(v uint64)

func (*OneOfs) String

func (x *OneOfs) String() string

func (*OneOfs) Unmarshal

func (m *OneOfs) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

func (*OneOfs) WhichThing

func (x *OneOfs) WhichThing() case_OneOfs_Thing

type OneOfs_builder

type OneOfs_builder struct {

	// Fields of oneof xxx_hidden_Thing:
	Bools      *bool
	Strings    *string
	Int32S     *int32
	Int64S     *int64
	Uint32S    *uint32
	Uint64S    *uint64
	Sint32S    *int32
	Sint64S    *int64
	Fixed32S   *uint32
	Fixed64S   *uint64
	Sfixed32S  *int32
	Sfixed64S  *int64
	Floats     *float32
	Doubles    *float64
	Nulls      *structpb.NullValue
	Structs    *structpb.Struct
	Timestamps *timestamppb.Timestamp
	Objects    *MapObject
	// contains filtered or unexported fields
}

func (OneOfs_builder) Build

func (b0 OneOfs_builder) Build() *OneOfs

type Optionals

type Optionals struct {
	XXX_raceDetectHookData protoimpl.RaceDetectHookData
	XXX_presence           [1]uint32
	// contains filtered or unexported fields
}

func (*Optionals) ClearOptionalBool

func (x *Optionals) ClearOptionalBool()

func (*Optionals) ClearOptionalBytes

func (x *Optionals) ClearOptionalBytes()

func (*Optionals) ClearOptionalDouble

func (x *Optionals) ClearOptionalDouble()

func (*Optionals) ClearOptionalEnum

func (x *Optionals) ClearOptionalEnum()

func (*Optionals) ClearOptionalFixed32

func (x *Optionals) ClearOptionalFixed32()

func (*Optionals) ClearOptionalFixed64

func (x *Optionals) ClearOptionalFixed64()

func (*Optionals) ClearOptionalFloat

func (x *Optionals) ClearOptionalFloat()

func (*Optionals) ClearOptionalInt32

func (x *Optionals) ClearOptionalInt32()

func (*Optionals) ClearOptionalInt64

func (x *Optionals) ClearOptionalInt64()

func (*Optionals) ClearOptionalMessage

func (x *Optionals) ClearOptionalMessage()

func (*Optionals) ClearOptionalSfixed32

func (x *Optionals) ClearOptionalSfixed32()

func (*Optionals) ClearOptionalSfixed64

func (x *Optionals) ClearOptionalSfixed64()

func (*Optionals) ClearOptionalSint32

func (x *Optionals) ClearOptionalSint32()

func (*Optionals) ClearOptionalSint64

func (x *Optionals) ClearOptionalSint64()

func (*Optionals) ClearOptionalString

func (x *Optionals) ClearOptionalString()

func (*Optionals) ClearOptionalUint32

func (x *Optionals) ClearOptionalUint32()

func (*Optionals) ClearOptionalUint64

func (x *Optionals) ClearOptionalUint64()

func (*Optionals) GetOptionalBool

func (x *Optionals) GetOptionalBool() bool

func (*Optionals) GetOptionalBytes

func (x *Optionals) GetOptionalBytes() []byte

func (*Optionals) GetOptionalDouble

func (x *Optionals) GetOptionalDouble() float64

func (*Optionals) GetOptionalEnum

func (x *Optionals) GetOptionalEnum() EventType

func (*Optionals) GetOptionalFixed32

func (x *Optionals) GetOptionalFixed32() uint32

func (*Optionals) GetOptionalFixed64

func (x *Optionals) GetOptionalFixed64() uint64

func (*Optionals) GetOptionalFloat

func (x *Optionals) GetOptionalFloat() float32

func (*Optionals) GetOptionalInt32

func (x *Optionals) GetOptionalInt32() int32

func (*Optionals) GetOptionalInt64

func (x *Optionals) GetOptionalInt64() int64

func (*Optionals) GetOptionalMessage

func (x *Optionals) GetOptionalMessage() *EmbeddedEvent

func (*Optionals) GetOptionalSfixed32

func (x *Optionals) GetOptionalSfixed32() int32

func (*Optionals) GetOptionalSfixed64

func (x *Optionals) GetOptionalSfixed64() int64

func (*Optionals) GetOptionalSint32

func (x *Optionals) GetOptionalSint32() int32

func (*Optionals) GetOptionalSint64

func (x *Optionals) GetOptionalSint64() int64

func (*Optionals) GetOptionalString

func (x *Optionals) GetOptionalString() string

func (*Optionals) GetOptionalUint32

func (x *Optionals) GetOptionalUint32() uint32

func (*Optionals) GetOptionalUint64

func (x *Optionals) GetOptionalUint64() uint64

func (*Optionals) HasOptionalBool

func (x *Optionals) HasOptionalBool() bool

func (*Optionals) HasOptionalBytes

func (x *Optionals) HasOptionalBytes() bool

func (*Optionals) HasOptionalDouble

func (x *Optionals) HasOptionalDouble() bool

func (*Optionals) HasOptionalEnum

func (x *Optionals) HasOptionalEnum() bool

func (*Optionals) HasOptionalFixed32

func (x *Optionals) HasOptionalFixed32() bool

func (*Optionals) HasOptionalFixed64

func (x *Optionals) HasOptionalFixed64() bool

func (*Optionals) HasOptionalFloat

func (x *Optionals) HasOptionalFloat() bool

func (*Optionals) HasOptionalInt32

func (x *Optionals) HasOptionalInt32() bool

func (*Optionals) HasOptionalInt64

func (x *Optionals) HasOptionalInt64() bool

func (*Optionals) HasOptionalMessage

func (x *Optionals) HasOptionalMessage() bool

func (*Optionals) HasOptionalSfixed32

func (x *Optionals) HasOptionalSfixed32() bool

func (*Optionals) HasOptionalSfixed64

func (x *Optionals) HasOptionalSfixed64() bool

func (*Optionals) HasOptionalSint32

func (x *Optionals) HasOptionalSint32() bool

func (*Optionals) HasOptionalSint64

func (x *Optionals) HasOptionalSint64() bool

func (*Optionals) HasOptionalString

func (x *Optionals) HasOptionalString() bool

func (*Optionals) HasOptionalUint32

func (x *Optionals) HasOptionalUint32() bool

func (*Optionals) HasOptionalUint64

func (x *Optionals) HasOptionalUint64() bool

func (*Optionals) Marshal

func (m *Optionals) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*Optionals) MarshalSize added in v0.4.0

func (m *Optionals) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*Optionals) MarshalTo

func (m *Optionals) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*Optionals) ProtoMessage

func (*Optionals) ProtoMessage()

func (*Optionals) ProtoReflect

func (x *Optionals) ProtoReflect() protoreflect.Message

func (*Optionals) Reset

func (x *Optionals) Reset()

func (*Optionals) SetOptionalBool

func (x *Optionals) SetOptionalBool(v bool)

func (*Optionals) SetOptionalBytes

func (x *Optionals) SetOptionalBytes(v []byte)

func (*Optionals) SetOptionalDouble

func (x *Optionals) SetOptionalDouble(v float64)

func (*Optionals) SetOptionalEnum

func (x *Optionals) SetOptionalEnum(v EventType)

func (*Optionals) SetOptionalFixed32

func (x *Optionals) SetOptionalFixed32(v uint32)

func (*Optionals) SetOptionalFixed64

func (x *Optionals) SetOptionalFixed64(v uint64)

func (*Optionals) SetOptionalFloat

func (x *Optionals) SetOptionalFloat(v float32)

func (*Optionals) SetOptionalInt32

func (x *Optionals) SetOptionalInt32(v int32)

func (*Optionals) SetOptionalInt64

func (x *Optionals) SetOptionalInt64(v int64)

func (*Optionals) SetOptionalMessage

func (x *Optionals) SetOptionalMessage(v *EmbeddedEvent)

func (*Optionals) SetOptionalSfixed32

func (x *Optionals) SetOptionalSfixed32(v int32)

func (*Optionals) SetOptionalSfixed64

func (x *Optionals) SetOptionalSfixed64(v int64)

func (*Optionals) SetOptionalSint32

func (x *Optionals) SetOptionalSint32(v int32)

func (*Optionals) SetOptionalSint64

func (x *Optionals) SetOptionalSint64(v int64)

func (*Optionals) SetOptionalString

func (x *Optionals) SetOptionalString(v string)

func (*Optionals) SetOptionalUint32

func (x *Optionals) SetOptionalUint32(v uint32)

func (*Optionals) SetOptionalUint64

func (x *Optionals) SetOptionalUint64(v uint64)

func (*Optionals) String

func (x *Optionals) String() string

func (*Optionals) Unmarshal

func (m *Optionals) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

type Optionals_builder

type Optionals_builder struct {
	OptionalString   *string
	OptionalBool     *bool
	OptionalInt32    *int32
	OptionalInt64    *int64
	OptionalUint32   *uint32
	OptionalUint64   *uint64
	OptionalSint32   *int32
	OptionalSint64   *int64
	OptionalFixed32  *uint32
	OptionalFixed64  *uint64
	OptionalSfixed32 *int32
	OptionalSfixed64 *int64
	OptionalFloat    *float32
	OptionalDouble   *float64
	OptionalEnum     *EventType
	OptionalBytes    []byte
	OptionalMessage  *EmbeddedEvent
	// contains filtered or unexported fields
}

func (Optionals_builder) Build

func (b0 Optionals_builder) Build() *Optionals

type RepeatAllTheThings

type RepeatAllTheThings struct {
	XXX_raceDetectHookData protoimpl.RaceDetectHookData
	XXX_presence           [1]uint32
	// contains filtered or unexported fields
}

func (*RepeatAllTheThings) ClearId

func (x *RepeatAllTheThings) ClearId()

func (*RepeatAllTheThings) GetId

func (x *RepeatAllTheThings) GetId() int32

func (*RepeatAllTheThings) GetTheBools

func (x *RepeatAllTheThings) GetTheBools() []bool

func (*RepeatAllTheThings) GetTheBytes

func (x *RepeatAllTheThings) GetTheBytes() [][]byte

func (*RepeatAllTheThings) GetTheDoubles

func (x *RepeatAllTheThings) GetTheDoubles() []float64

func (*RepeatAllTheThings) GetTheEventTypes

func (x *RepeatAllTheThings) GetTheEventTypes() []EventType

func (*RepeatAllTheThings) GetTheFixed32S

func (x *RepeatAllTheThings) GetTheFixed32S() []uint32

func (*RepeatAllTheThings) GetTheFixed64S

func (x *RepeatAllTheThings) GetTheFixed64S() []uint64

func (*RepeatAllTheThings) GetTheFloats

func (x *RepeatAllTheThings) GetTheFloats() []float32

func (*RepeatAllTheThings) GetTheInt32S

func (x *RepeatAllTheThings) GetTheInt32S() []int32

func (*RepeatAllTheThings) GetTheInt64S

func (x *RepeatAllTheThings) GetTheInt64S() []int64

func (*RepeatAllTheThings) GetTheMessages

func (x *RepeatAllTheThings) GetTheMessages() []*EmbeddedEvent

func (*RepeatAllTheThings) GetTheSfixed32S

func (x *RepeatAllTheThings) GetTheSfixed32S() []int32

func (*RepeatAllTheThings) GetTheSfixed64S

func (x *RepeatAllTheThings) GetTheSfixed64S() []int64

func (*RepeatAllTheThings) GetTheSint32S

func (x *RepeatAllTheThings) GetTheSint32S() []int32

func (*RepeatAllTheThings) GetTheSint64S

func (x *RepeatAllTheThings) GetTheSint64S() []int64

func (*RepeatAllTheThings) GetTheStrings

func (x *RepeatAllTheThings) GetTheStrings() []string

func (*RepeatAllTheThings) GetTheUint32S

func (x *RepeatAllTheThings) GetTheUint32S() []uint32

func (*RepeatAllTheThings) GetTheUint64S

func (x *RepeatAllTheThings) GetTheUint64S() []uint64

func (*RepeatAllTheThings) HasId

func (x *RepeatAllTheThings) HasId() bool

func (*RepeatAllTheThings) Marshal

func (m *RepeatAllTheThings) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*RepeatAllTheThings) MarshalSize added in v0.4.0

func (m *RepeatAllTheThings) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*RepeatAllTheThings) MarshalTo

func (m *RepeatAllTheThings) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*RepeatAllTheThings) ProtoMessage

func (*RepeatAllTheThings) ProtoMessage()

func (*RepeatAllTheThings) ProtoReflect

func (x *RepeatAllTheThings) ProtoReflect() protoreflect.Message

func (*RepeatAllTheThings) Reset

func (x *RepeatAllTheThings) Reset()

func (*RepeatAllTheThings) SetId

func (x *RepeatAllTheThings) SetId(v int32)

func (*RepeatAllTheThings) SetTheBools

func (x *RepeatAllTheThings) SetTheBools(v []bool)

func (*RepeatAllTheThings) SetTheBytes

func (x *RepeatAllTheThings) SetTheBytes(v [][]byte)

func (*RepeatAllTheThings) SetTheDoubles

func (x *RepeatAllTheThings) SetTheDoubles(v []float64)

func (*RepeatAllTheThings) SetTheEventTypes

func (x *RepeatAllTheThings) SetTheEventTypes(v []EventType)

func (*RepeatAllTheThings) SetTheFixed32S

func (x *RepeatAllTheThings) SetTheFixed32S(v []uint32)

func (*RepeatAllTheThings) SetTheFixed64S

func (x *RepeatAllTheThings) SetTheFixed64S(v []uint64)

func (*RepeatAllTheThings) SetTheFloats

func (x *RepeatAllTheThings) SetTheFloats(v []float32)

func (*RepeatAllTheThings) SetTheInt32S

func (x *RepeatAllTheThings) SetTheInt32S(v []int32)

func (*RepeatAllTheThings) SetTheInt64S

func (x *RepeatAllTheThings) SetTheInt64S(v []int64)

func (*RepeatAllTheThings) SetTheMessages

func (x *RepeatAllTheThings) SetTheMessages(v []*EmbeddedEvent)

func (*RepeatAllTheThings) SetTheSfixed32S

func (x *RepeatAllTheThings) SetTheSfixed32S(v []int32)

func (*RepeatAllTheThings) SetTheSfixed64S

func (x *RepeatAllTheThings) SetTheSfixed64S(v []int64)

func (*RepeatAllTheThings) SetTheSint32S

func (x *RepeatAllTheThings) SetTheSint32S(v []int32)

func (*RepeatAllTheThings) SetTheSint64S

func (x *RepeatAllTheThings) SetTheSint64S(v []int64)

func (*RepeatAllTheThings) SetTheStrings

func (x *RepeatAllTheThings) SetTheStrings(v []string)

func (*RepeatAllTheThings) SetTheUint32S

func (x *RepeatAllTheThings) SetTheUint32S(v []uint32)

func (*RepeatAllTheThings) SetTheUint64S

func (x *RepeatAllTheThings) SetTheUint64S(v []uint64)

func (*RepeatAllTheThings) String

func (x *RepeatAllTheThings) String() string

func (*RepeatAllTheThings) Unmarshal

func (m *RepeatAllTheThings) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

type RepeatAllTheThings_builder

type RepeatAllTheThings_builder struct {
	Id            *int32
	TheStrings    []string
	TheBools      []bool
	TheInt32S     []int32
	TheInt64S     []int64
	TheUint32S    []uint32
	TheUint64S    []uint64
	TheSint32S    []int32
	TheSint64S    []int64
	TheFixed32S   []uint32
	TheFixed64S   []uint64
	TheSfixed32S  []int32
	TheSfixed64S  []int64
	TheFloats     []float32
	TheDoubles    []float64
	TheEventTypes []EventType
	TheBytes      [][]byte
	TheMessages   []*EmbeddedEvent
	// contains filtered or unexported fields
}

func (RepeatAllTheThings_builder) Build

type TestEvent

type TestEvent struct {
	XXX_raceDetectHookData protoimpl.RaceDetectHookData
	XXX_presence           [1]uint32
	// contains filtered or unexported fields
}

func (*TestEvent) ClearEmbedded

func (x *TestEvent) ClearEmbedded()

func (*TestEvent) ClearInfo

func (x *TestEvent) ClearInfo()

func (*TestEvent) ClearIsAwesome

func (x *TestEvent) ClearIsAwesome()

func (*TestEvent) ClearJedi

func (x *TestEvent) ClearJedi()

func (*TestEvent) ClearName

func (x *TestEvent) ClearName()

func (*TestEvent) ClearNested

func (x *TestEvent) ClearNested()

func (*TestEvent) ClearNullVal

func (x *TestEvent) ClearNullVal()

func (*TestEvent) ClearOneofs

func (x *TestEvent) ClearOneofs()

func (*TestEvent) ClearOther

func (x *TestEvent) ClearOther()

func (*TestEvent) ClearPath

func (x *TestEvent) ClearPath()

func (*TestEvent) ClearSith

func (x *TestEvent) ClearSith()

func (*TestEvent) ClearStructs

func (x *TestEvent) ClearStructs()

func (*TestEvent) ClearTimestamps

func (x *TestEvent) ClearTimestamps()

func (*TestEvent) ClearTs

func (x *TestEvent) ClearTs()

func (*TestEvent) GetEmbedded

func (x *TestEvent) GetEmbedded() *EmbeddedEvent

func (*TestEvent) GetInfo

func (x *TestEvent) GetInfo() string

func (*TestEvent) GetIsAwesome

func (x *TestEvent) GetIsAwesome() bool

func (*TestEvent) GetJedi

func (x *TestEvent) GetJedi() bool

func (*TestEvent) GetLabels

func (x *TestEvent) GetLabels() []string

func (*TestEvent) GetName

func (x *TestEvent) GetName() string

func (*TestEvent) GetNested

func (x *TestEvent) GetNested() *TestEvent_NestedMsg

func (*TestEvent) GetNullVal

func (x *TestEvent) GetNullVal() structpb.NullValue

func (*TestEvent) GetOther

func (x *TestEvent) GetOther() string

func (*TestEvent) GetSith

func (x *TestEvent) GetSith() bool

func (*TestEvent) GetStructs

func (x *TestEvent) GetStructs() *structpb.Struct

func (*TestEvent) GetTimestamps

func (x *TestEvent) GetTimestamps() *timestamppb.Timestamp

func (*TestEvent) GetTs

func (x *TestEvent) GetTs() *timestamppb.Timestamp

func (*TestEvent) HasEmbedded

func (x *TestEvent) HasEmbedded() bool

func (*TestEvent) HasInfo

func (x *TestEvent) HasInfo() bool

func (*TestEvent) HasIsAwesome

func (x *TestEvent) HasIsAwesome() bool

func (*TestEvent) HasJedi

func (x *TestEvent) HasJedi() bool

func (*TestEvent) HasName

func (x *TestEvent) HasName() bool

func (*TestEvent) HasNested

func (x *TestEvent) HasNested() bool

func (*TestEvent) HasNullVal

func (x *TestEvent) HasNullVal() bool

func (*TestEvent) HasOneofs

func (x *TestEvent) HasOneofs() bool

func (*TestEvent) HasOther

func (x *TestEvent) HasOther() bool

func (*TestEvent) HasPath

func (x *TestEvent) HasPath() bool

func (*TestEvent) HasSith

func (x *TestEvent) HasSith() bool

func (*TestEvent) HasStructs

func (x *TestEvent) HasStructs() bool

func (*TestEvent) HasTimestamps

func (x *TestEvent) HasTimestamps() bool

func (*TestEvent) HasTs

func (x *TestEvent) HasTs() bool

func (*TestEvent) Marshal

func (m *TestEvent) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*TestEvent) MarshalSize added in v0.4.0

func (m *TestEvent) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*TestEvent) MarshalTo

func (m *TestEvent) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*TestEvent) ProtoMessage

func (*TestEvent) ProtoMessage()

func (*TestEvent) ProtoReflect

func (x *TestEvent) ProtoReflect() protoreflect.Message

func (*TestEvent) Reset

func (x *TestEvent) Reset()

func (*TestEvent) SetEmbedded

func (x *TestEvent) SetEmbedded(v *EmbeddedEvent)

func (*TestEvent) SetInfo

func (x *TestEvent) SetInfo(v string)

func (*TestEvent) SetIsAwesome

func (x *TestEvent) SetIsAwesome(v bool)

func (*TestEvent) SetJedi

func (x *TestEvent) SetJedi(v bool)

func (*TestEvent) SetLabels

func (x *TestEvent) SetLabels(v []string)

func (*TestEvent) SetName

func (x *TestEvent) SetName(v string)

func (*TestEvent) SetNested

func (x *TestEvent) SetNested(v *TestEvent_NestedMsg)

func (*TestEvent) SetNullVal

func (x *TestEvent) SetNullVal(v structpb.NullValue)

func (*TestEvent) SetOther

func (x *TestEvent) SetOther(v string)

func (*TestEvent) SetSith

func (x *TestEvent) SetSith(v bool)

func (*TestEvent) SetStructs

func (x *TestEvent) SetStructs(v *structpb.Struct)

func (*TestEvent) SetTimestamps

func (x *TestEvent) SetTimestamps(v *timestamppb.Timestamp)

func (*TestEvent) SetTs

func (x *TestEvent) SetTs(v *timestamppb.Timestamp)

func (*TestEvent) String

func (x *TestEvent) String() string

func (*TestEvent) Unmarshal

func (m *TestEvent) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

func (*TestEvent) WhichOneofs

func (x *TestEvent) WhichOneofs() case_TestEvent_Oneofs

func (*TestEvent) WhichPath

func (x *TestEvent) WhichPath() case_TestEvent_Path

type TestEvent_NestedMsg

type TestEvent_NestedMsg struct {
	XXX_raceDetectHookData protoimpl.RaceDetectHookData
	XXX_presence           [1]uint32
	// contains filtered or unexported fields
}

func (*TestEvent_NestedMsg) ClearDetails

func (x *TestEvent_NestedMsg) ClearDetails()

func (*TestEvent_NestedMsg) GetDetails

func (x *TestEvent_NestedMsg) GetDetails() string

func (*TestEvent_NestedMsg) HasDetails

func (x *TestEvent_NestedMsg) HasDetails() bool

func (*TestEvent_NestedMsg) Marshal

func (m *TestEvent_NestedMsg) Marshal() ([]byte, error)

Marshal converts the contents of m to the Protobuf binary encoding and returns the result or an error.

func (*TestEvent_NestedMsg) MarshalSize added in v0.4.0

func (m *TestEvent_NestedMsg) MarshalSize() int

MarshalSize calculates and returns the size (in bytes) required to hold the contents of m using the Protobuf binary encoding.

func (*TestEvent_NestedMsg) MarshalTo

func (m *TestEvent_NestedMsg) MarshalTo(dest []byte) error

MarshalTo converts the contents of m to the Protobuf binary encoding and writes the result to dest.

func (*TestEvent_NestedMsg) ProtoMessage

func (*TestEvent_NestedMsg) ProtoMessage()

func (*TestEvent_NestedMsg) ProtoReflect

func (x *TestEvent_NestedMsg) ProtoReflect() protoreflect.Message

func (*TestEvent_NestedMsg) Reset

func (x *TestEvent_NestedMsg) Reset()

func (*TestEvent_NestedMsg) SetDetails

func (x *TestEvent_NestedMsg) SetDetails(v string)

func (*TestEvent_NestedMsg) String

func (x *TestEvent_NestedMsg) String() string

func (*TestEvent_NestedMsg) Unmarshal

func (m *TestEvent_NestedMsg) Unmarshal(p []byte) error

Unmarshal decodes a binary encoded Protobuf message from p and populates m with the result.

type TestEvent_NestedMsg_builder

type TestEvent_NestedMsg_builder struct {
	Details *string
	// contains filtered or unexported fields
}

func (TestEvent_NestedMsg_builder) Build

type TestEvent_builder

type TestEvent_builder struct {
	Name      *string
	Info      *string
	IsAwesome *bool
	Labels    []string
	Embedded  *EmbeddedEvent
	// Fields of oneof xxx_hidden_Path:
	Jedi  *bool
	Sith  *bool
	Other *string
	// -- end of xxx_hidden_Path
	Nested  *TestEvent_NestedMsg
	Ts      *timestamppb.Timestamp
	NullVal *structpb.NullValue
	// Fields of oneof xxx_hidden_Oneofs:
	Timestamps *timestamppb.Timestamp
	Structs    *structpb.Struct
	// contains filtered or unexported fields
}

func (TestEvent_builder) Build

func (b0 TestEvent_builder) Build() *TestEvent

Jump to